@@ -3,6 +3,8 @@ from paste.httpexceptions import HTTPExceptionHandler
 
 from pkg_resources import iter_entry_points
 
+from svenweb.template_loader import TempitaLoader
+
 def factory(global_conf, **app_conf):
     """create a webob view and wrap it in middleware"""
     key_str = 'svenweb.'
@@ -10,6 +12,13 @@ def factory(global_conf, **app_conf):
                  for key, value in app_conf.items()
                  if key.startswith(key_str) ])
 
-    app = SvnWikiView(**args)
+    templates_dir = args['templates_dir']
+    template_loader = TempitaLoader(templates_dir)
+
+    del args['templates_dir']
+
+    app = SvnWikiView(
+        template_loader=template_loader, 
+        **args)
 
     return HTTPExceptionHandler(app)
